@@ -33,21 +33,6 @@
 static const guint speedList[] = {9600, 19200, 38400, 57600, 115200, 0};
 #define  DEFAULT_SPEED_INDEX  3  /* Default to 57600 */
 
-static const char *synctypes[] = {_("Use conduit settings"),
-				  _("Synchronize"),
-				  _("Copy from pilot"),
-				  _("Copy to pilot"),
-				  _("Merge from pilot"),
-				  _("Merge to pilot"),
-				  NULL};
-static const guint syncvalues[] = {GnomePilotConduitSyncTypeNotSet,
-				   GnomePilotConduitSyncTypeSynchronize,
-				   GnomePilotConduitSyncTypeCopyFromPilot,
-				   GnomePilotConduitSyncTypeCopyToPilot,
-				   GnomePilotConduitSyncTypeMergeFromPilot,
-				   GnomePilotConduitSyncTypeMergeToPilot};
-
-
 void
 fill_speed_menu (GtkOptionMenu *option_menu, guint default_speed)
 {
@@ -206,7 +191,11 @@ real_choose_pilot_dialog (PilotState *state)
 	tmp = state->devices;
 	while (tmp != NULL){
 		dev =(GPilotDevice*)tmp->data;
-		menu_item = gtk_menu_item_new_with_label (dev->port);
+		if(dev->type == PILOT_DEVICE_NETWORK) {
+			menu_item = gtk_menu_item_new_with_label ("[network]");
+		} else {
+			menu_item = gtk_menu_item_new_with_label (dev->port);
+		}
 		gtk_object_set_data (GTK_OBJECT (menu_item), "device", dev);
 		gtk_widget_show (menu_item);
 		gtk_menu_append (GTK_MENU (menu), menu_item);
@@ -215,12 +204,13 @@ real_choose_pilot_dialog (PilotState *state)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
 	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), 0);
 
-	if (gnome_dialog_run_and_close (GNOME_DIALOG (dlg)) == 0) {
+	if (GTK_RESPONSE_OK == gtk_dialog_run (GTK_DIALOG (dlg))) {
 		menu_item = gtk_menu_get_active (GTK_MENU (menu));
 		dev = (GPilotDevice *)gtk_object_get_data (GTK_OBJECT (menu_item), "device");
 	} else {
 		dev = NULL;
 	}
+	gtk_widget_hide(dlg);
 
 	return dev;
 }
@@ -245,7 +235,7 @@ get_default_pilot (PilotState *state)
 {
 	GPilotPilot *pilot = g_new0 (GPilotPilot, 1);
 	
-	pilot->pilot_username = g_get_real_name ();
+	pilot->pilot_username = g_strdup(g_get_real_name ());
 	pilot->pilot_id = getuid ();
 	pilot->name = next_pilot_name (state);
 	pilot->sync_options.basedir = g_concat_dir_and_file (g_get_home_dir (), pilot->name);
@@ -317,13 +307,18 @@ insert_device_callback (GtkEditable *editable, const gchar *text,
 
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
-		if (text[0]!='/') {
+		if (text[0]!='/'
+#ifdef PILOT_LINK_0_12
+		    /* usb: pseudo-device is available from pilot-link 0.12.0 */
+		    && text[0]!='u'
+#endif
+		    ) {
 			gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
 			return;
 		} 
 	} else {
 		for (i =0;i<len;i++)
-			if (!(isalnum (text[i]) || text[i]=='/')) {
+			if (!(isalnum (text[i]) || text[i]=='/' || text[i]==':')) {
 				gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
 				return;
 			}
@@ -367,7 +362,7 @@ next_cradle_name (PilotState *state)
 	return g_strdup (buf);
 }
 
-/* find the next "MyPilot#" name that is available for use */
+/* find the next "MyPDA#" name that is available for use */
 
 static gint 
 compare_pilot_name (GPilotPilot *pilot, gchar *name)
@@ -381,12 +376,12 @@ next_pilot_name (PilotState *state)
 	int i =0;
 	gchar buf[16];
 	
-	sprintf (buf,"MyPilot");
+	sprintf (buf,"MyPDA");
 	
 	while (g_list_find_custom (state->pilots, buf,
 				   (GCompareFunc)compare_pilot_name)!= NULL) {
 		i++;
-		sprintf (buf,"MyPilot%d",i);
+		sprintf (buf,"MyPDA%d",i);
 	}
 	return g_strdup (buf);
 }
@@ -396,10 +391,10 @@ sync_type_to_str (GnomePilotConduitSyncType t)
 {
 	switch (t) {
 	case GnomePilotConduitSyncTypeSynchronize:    return _("Synchronize");
-	case GnomePilotConduitSyncTypeCopyFromPilot:  return _("Copy from pilot");
-	case GnomePilotConduitSyncTypeCopyToPilot:    return _("Copy to pilot");
-	case GnomePilotConduitSyncTypeMergeFromPilot: return _("Merge from pilot");
-	case GnomePilotConduitSyncTypeMergeToPilot:   return _("Merge to pilot");
+	case GnomePilotConduitSyncTypeCopyFromPilot:  return _("Copy from PDA");
+	case GnomePilotConduitSyncTypeCopyToPilot:    return _("Copy to PDA");
+	case GnomePilotConduitSyncTypeMergeFromPilot: return _("Merge from PDA");
+	case GnomePilotConduitSyncTypeMergeToPilot:   return _("Merge to PDA");
 	case GnomePilotConduitSyncTypeCustom: 
 	case GnomePilotConduitSyncTypeNotSet:     
 	default:                                      return _("Use conduit settings");
@@ -574,8 +569,24 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 gboolean
 check_device_settings (GPilotDevice *device)
 {
-	char *str;
 	
+	char *str;
+	struct stat buf;
+#ifndef WITH_HAL
+	char *usbdevicesfile_str ="/proc/bus/usb/devices";
+	char *sysfs_dir = "/sys/bus/usb/devices";
+#endif
+
+#ifdef PILOT_LINK_0_12
+	if (strcmp(device->port, "usb:") == 0 && device->type != PILOT_DEVICE_NETWORK
+	    && device->type != PILOT_DEVICE_USB_VISOR) {
+		str = g_strdup (_("Device 'usb:' is only valid for devices of type USB"));
+		error_dialog (NULL, str);
+		g_free (str);
+		return FALSE;
+	}
+#endif
+
 	if (device->type == PILOT_DEVICE_SERIAL) {
 		g_message ("checking rw on %s", device->port);
 		if (access (device->port, R_OK|W_OK)) {
@@ -587,7 +598,25 @@ check_device_settings (GPilotDevice *device)
 			g_free (str);
 			return FALSE;
 		}
-	}
+#ifndef WITH_HAL
+	} else if (device->type == PILOT_DEVICE_USB_VISOR) {
+		/* check sysfs or usbfs is mounted */
+		if(stat(sysfs_dir, &buf) != 0 &&
+		    ((stat (usbdevicesfile_str, &buf) != 0 &&
+		      stat ("/proc/bus/usb/devices_please-use-sysfs-instead", &buf) != 0) ||
+		    !(S_ISREG(buf.st_mode)) ||
+		    !(buf.st_mode & S_IRUSR))) {
+			str = g_strdup_printf (
+			    _("Failed to find directory %s or read file %s.  "
+				"Check that usbfs or sysfs is mounted."),
+			    sysfs_dir,
+			    usbdevicesfile_str);
+			error_dialog (NULL, str);
+			g_free (str);
+			return FALSE;
+		}
+#endif
+	} 
 
 	return TRUE;
 }
