@@ -484,7 +484,7 @@ gnome_pilot_conduit_standard_real_copy_to_pilot (GnomePilotConduitStandard *cond
 	conduit->total_progress += conduit->num_updated_local_records;
 
 	if (sync_CopyToPilot (sh) != 0) {
-		g_warning(_("Copy to pilot failed!"));
+		g_warning(_("Copy to PDA failed!"));
 		return -1;
 	}
 
@@ -508,7 +508,7 @@ gnome_pilot_conduit_standard_real_copy_from_pilot (GnomePilotConduitStandard *co
 	sh = sync_abs_new_sync_handler (conduit, dbinfo);
 
 	if (sync_CopyFromPilot (sh) != 0) {
-		g_warning(_("Copy from pilot failed!"));
+		g_warning(_("Copy from PDA failed!"));
 		return -1;
 	}
 
@@ -532,7 +532,7 @@ gnome_pilot_conduit_standard_real_merge_to_pilot (GnomePilotConduitStandard *con
 	sh = sync_abs_new_sync_handler (conduit, dbinfo);
 
 	if (sync_MergeToPilot (sh) != 0) {
-		g_warning(_("Merge to pilot failed!"));
+		g_warning(_("Merge to PDA failed!"));
 		return -1;
 	}
 
@@ -556,7 +556,7 @@ gnome_pilot_conduit_standard_real_merge_from_pilot (GnomePilotConduitStandard *c
 	sh = sync_abs_new_sync_handler (conduit, dbinfo);
 
 	if (sync_MergeFromPilot (sh) != 0) {
-		g_warning(_("Merge from pilot failed!"));
+		g_warning(_("Merge from PDA failed!"));
 		return -1;
 	}
 
